Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Pinpoint Email Service.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, resources, and condition keys for Amazon Pinpoint Email Service - AWS Identity and Access Management

# Actions, resources, and condition keys for Amazon Pinpoint Email Service

Tip

This page is moving to a new location on November 16, 2020. Please update your bookmark to use the new page at https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonpinpointemailservice.html .

Amazon Pinpoint Email Service (service prefix: `ses` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- View a list of the API operations available for this service .

Topics

- Actions defined by Amazon Pinpoint Email Service
- Resource types defined by Amazon Pinpoint Email Service
- Condition keys for Amazon Pinpoint Email Service

## Actions defined by Amazon Pinpoint Email Service

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateConfigurationSet | Create a configuration set. Configuration sets are groups of rules that you can apply to the emails you send using Amazon Pinpoint | Write | configuration-set* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateConfigurationSetEventDestination | Create an event destination | Write | configuration-set* |  |
CreateDedicatedIpPool | Create a new pool of dedicated IP addresses | Write | dedicated-ip-pool* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateDeliverabilityTestReport | Create a new predictive inbox placement test. | Write | identity* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateEmailIdentity | Verifies an email identity for use with Amazon Pinpoint | Write | identity* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
DeleteConfigurationSet | Delete an existing configuration set | Write | configuration-set* |  |
DeleteConfigurationSetEventDestination | Delete an event destination | Write | configuration-set* |  |
DeleteDedicatedIpPool | Delete a dedicated IP pool | Write | dedicated-ip-pool* |  |
DeleteEmailIdentity | Deletes an email identity that you previously verified for use with Amazon Pinpoint | Write | identity* |  |
GetAccount | Obtain information about the email-sending status and capabilities | Read |  |  |
GetBlacklistReports | Retrieve a list of the blacklists that your dedicated IP addresses appear on | Read |  |  |
GetConfigurationSet | Get information about an existing configuration set | Read | configuration-set* |  |
GetConfigurationSetEventDestinations | Retrieve a list of event destinations that are associated with a configuration set | Read | configuration-set* |  |
GetDedicatedIp | Get information about a dedicated IP address | Read |  |  |
GetDedicatedIps | List the dedicated IP addresses that are associated with your Amazon Pinpoint account | Read | dedicated-ip-pool* |  |
GetDeliverabilityDashboardOptions | Show the status of the Deliverability dashboard | Read |  |  |
GetDeliverabilityTestReport | Retrieve the results of a predictive inbox placement test | Read | deliverability-test-report* |  |
GetDomainStatisticsReport | Retrieve inbox placement and engagement rates for the domains that you use to send email | Read | identity* |  |
GetEmailIdentity | Provides information about a specific identity associated with your Amazon Pinpoint account | Read | identity* |  |
ListConfigurationSets | List all of the configuration sets associated with your Amazon Pinpoint account in the current region | List |  |  |
ListDedicatedIpPools | List all of the dedicated IP pools that exist in your Amazon Pinpoint account in the current AWS Region | List |  |  |
ListDeliverabilityTestReports | Show a list of the predictive inbox placement tests that you've performed, regardless of their statuses | List |  |  |
ListEmailIdentities | Returns a list of all of the email identities that are associated with your Amazon Pinpoint account | List |  |  |
ListTagsForResource | Retrieve a list of the tags (keys and values) that are associated with a specific resource. | Read | configuration-set |  |
dedicated-ip-pool |  |
deliverability-test-report |  |
identity |  |
PutAccountDedicatedIpWarmupAttributes | Enable or disable the automatic warm-up feature for dedicated IP addresses | Write |  |  |
PutAccountSendingAttributes | Enable or disable the ability of your account to send email | Write |  |  |
PutConfigurationSetDeliveryOptions | Associate a configuration set with a dedicated IP pool | Write | configuration-set* |  |
PutConfigurationSetReputationOptions | Enable or disable collection of reputation metrics for emails that you send using a particular configuration set in a specific AWS Region | Write | configuration-set* |  |
PutConfigurationSetSendingOptions | Enable or disable email sending for messages that use a particular configuration set in a specific AWS Region | Write | configuration-set* |  |
PutConfigurationSetTrackingOptions | Specify a custom domain to use for open and click tracking elements in email that you send using Amazon Pinpoint | Write | configuration-set* |  |
PutDedicatedIpInPool | Move a dedicated IP address to an existing dedicated IP pool | Write | dedicated-ip-pool* |  |
PutDedicatedIpWarmupAttributes | Put Dedicated IP warm up attributes | Write |  |  |
PutDeliverabilityDashboardOption | Enable or disable the Deliverability dashboard | Write |  |  |
PutEmailIdentityDkimAttributes | Used to enable or disable DKIM authentication for an email identity | Write | identity* |  |
PutEmailIdentityFeedbackAttributes | Used to enable or disable feedback forwarding for an identity | Write | identity* |  |
PutEmailIdentityMailFromAttributes | Used to enable or disable the custom Mail-From domain configuration for an email identity | Write | identity* |  |
SendEmail | Sends an email message | Write | identity* |  |
| ses:FeedbackAddress ses:FromAddress ses:FromDisplayName ses:Recipients |
TagResource | Add one or more tags (keys and values) to a specified resource. | Tagging | configuration-set |  |
dedicated-ip-pool |  |
deliverability-test-report |  |
identity |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Remove one or more tags (keys and values) from a specified resource. | Tagging | configuration-set |  |
dedicated-ip-pool |  |
deliverability-test-report |  |
identity |  |
| aws:TagKeys |
UpdateConfigurationSetEventDestination | Update the configuration of an event destination for a configuration set | Write | configuration-set* |  |

## Resource types defined by Amazon Pinpoint Email Service

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
configuration-set | `arn:$ { Partition}:ses:$ { Region}:$ { Account}:configuration-set/$ { ConfigurationSetName}` | aws:ResourceTag/${TagKey}
dedicated-ip-pool | `arn:$ { Partition}:ses:$ { Region}:$ { Account}:dedicated-ip-pool/$ { CustomVerificationEmailTemplateName}` | aws:ResourceTag/${TagKey}
deliverability-test-report | `arn:$ { Partition}:ses:$ { Region}:$ { Account}:deliverability-test-report/$ { CustomVerificationEmailTemplateName}` | aws:ResourceTag/${TagKey}
event-destination | `arn:$ { Partition}:ses:$ { Region}:$ { Account}:configuration-set/$ { ConfigurationSetName}:event-destination/$ { EventDestinationName}` |
identity | `arn:$ { Partition}:ses:$ { Region}:$ { Account}:identity/$ { IdentityName}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Pinpoint Email Service

Amazon Pinpoint Email Service defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request | String
ses:FeedbackAddress | The "Return-Path" address, which specifies where bounces and complaints are sent by email feedback forwarding. | String
ses:FromAddress | The "From" address of a message. | String
ses:FromDisplayName | The "From" address that is used as the display name of a message. | String
ses:Recipients | The recipient addresses of a message, which include the "To", "CC", and "BCC" addresses. | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.